@@ -16,3 +16,13 @@ class ModelPermission(permissions.IsAuthenticated):
         if request.user.is_staff:
             return True
         return self.get_user_permission(request, view, obj)  # nocv
+
+
+class InventoryItemsPermission(permissions.IsAuthenticated):
+
+    def has_object_permission(self, request, view, obj):
+        if request.method.lower() == 'get':
+            return True
+        elif obj.master_project is None:
+            return True
+        return False
