@@ -6,6 +6,7 @@ import shutil
 import pathlib
 import logging
 import traceback
+from itertools import chain
 
 from six.moves.urllib.request import urlretrieve
 from django.db import transaction
@@ -180,27 +181,41 @@ class _Base:
         Find and update playbooks in project.
         :param files: list of filenames.
         '''
-        # reg = re.compile(self.regex)
-        # playbooks = filter(reg.match, files)
         self._set_tasks_list(files)
 
-    def _get_files(self, repo: Any = None) -> pathlib.Path:
-        '''
-        Get all files, where playbooks should be.
-        :param repo: Repo object
-        :type repo: object, None
-        :return: list of files in dir
-        :rtype: list
-        '''
-        # pylint: disable=unused-argument
-        return pathlib.Path(self.path)
-
     def search_files(self, repo: Any = None, pattern: Text = '**/*') -> Iterable[pathlib.Path]:
-        return self._get_files(repo).glob(pattern)
+        # pylint: disable=unused-argument
+        path = pathlib.Path(self.path)
+        return map(lambda x: x.relative_to(self.path), path.glob(pattern))
 
     def _operate(self, operation: Callable, **kwargs) -> Any:
         return operation(kwargs)
 
+    def _get_playbook_path(self, repo: Any = None) -> Iterable[pathlib.Path]:
+        path_list_additional = []
+        additional_pb_pattern = None
+
+        with raise_context():
+            additional_pb_pattern = self.proj.variables.get(key='playbook_path').value
+
+        if additional_pb_pattern and (pathlib.Path(self.path) / additional_pb_pattern).exists():
+            path_list_additional = self.search_files(repo, additional_pb_pattern  + '/*.yml')
+
+        return chain(self.search_files(repo, '*.yml'), path_list_additional)
+
+    def _update_slave_inventories(self, slave_inventory_list):
+        for slave_inv in slave_inventory_list:
+            ext = getattr(slave_inv.variables.filter(key='inventory_extension').last(), 'value', '')
+            file_path = pathlib.Path(f"{settings.PROJECTS_DIR}/{self.proj.id}/{slave_inv.name}{ext}")
+            if not file_path.exists():
+                slave_inv.delete()
+                continue
+            slave_inv.import_inventory_from_string(
+                raw_data=file_path.read_text(),
+                name=slave_inv.name,
+                inventory_instance=slave_inv
+            )
+
     def _make_operations(self, operation: Callable) -> Any:
         '''
         Handle VCS operations and sync data from project.
@@ -212,10 +227,12 @@ class _Base:
         try:
             with transaction.atomic():
                 result = self._operate(operation)
-                self._set_status("OK")
-                self._update_tasks(self.search_files(result[0], '*.yml'))
+                self.proj.status = "OK"
+                self._update_tasks(self._get_playbook_path(result[0]))
                 self._set_project_modules()
                 self._handle_yaml(self._load_yaml() or dict())
+                self._update_slave_inventories(self.proj.slave_inventory.all())
+                self.proj.save()
         except Exception as err:
             logger.debug(traceback.format_exc())
             self.message('Sync error: {}'.format(err), 'error')
